@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2015-2020 Rumma & Ko Ltd
+# Copyright 2015-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -35,7 +35,7 @@ from lino.sphinxcontrib.actordoc import menuselection_text
 from pprint import pprint
 from lino.utils.diag import visible_for
 from lino.core.utils import full_model_name
-from lino.core.utils import PseudoRequest
+# from lino.core.utils import PseudoRequest
 from lino.core.site import html2text
 
 from lino.core.menus import Menu
@@ -191,7 +191,7 @@ def show_menu_path(spec, language=None):
 def noblanklines(s):
     """Remove blank lines from output. This is used to increase
     readability when some expected output would otherweise contain
-    disturbing `<BLANKLINE>` which are not relevant to the test
+    disturbing `<BLANKLINE>` that are not relevant to the test
     itself.
 
     """
@@ -392,7 +392,7 @@ def walk_menu_items(username=None, severe=True):
 
 def show_sql_queries():
     """
-    Print the SQL queries which have been made since last call.
+    Print the SQL queries that have been made since last call.
 
     Usage example: :ref:`specs.noi.sql`.
     """
@@ -403,7 +403,7 @@ def show_sql_queries():
 
 
 def show_sql_summary(**kwargs):
-    """Print a summary of the SQL queries which have been made since last
+    """Print a summary of the SQL queries that have been made since last
     call.
 
     Usage example: :ref:`specs.tera.sql`.
@@ -507,10 +507,11 @@ def show_dashboard(username, **options):
 
 
     """
-    request = PseudoRequest(username)
-    ui = settings.SITE.kernel.text_renderer.front_end
-    html = settings.SITE.get_main_html(request, front_end=ui)
-    print(html2text(html, **options))
+    # request = PseudoRequest(username)
+    rnd = settings.SITE.kernel.text_renderer
+    ar = rt.login(username, renderer=rnd)
+    html = settings.SITE.get_main_html(ar) #, front_end=rnd.front_end)
+    print(html2text(html, **options).strip())
 
 def menu2rst(mnu, level=1):
     """Recursive utility used by :func:`show_menu`.
