@@ -15,6 +15,7 @@ import logging; logger = logging.getLogger(__name__)
 import copy
 import traceback
 from types import GeneratorType
+from inspect import getmro
 
 from django.db import models
 from django.conf import settings
@@ -175,6 +176,7 @@ class ActorMetaClass(type):
         cls._setup_done = False
         cls._setup_doing = False
         cls.virtual_fields = {}
+        # cls.extra_fields = {}
         cls._constants = {}
         cls._actions_dict = {}  # AttrDict()
         cls._actions_list = []  # 20121129
@@ -456,8 +458,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     insert_layout = None
     card_layout = None
     item_layout = None
-    """
-    Define a layout for a card view of the table."""
+    # item_layout = "overview"
 
     detail_template = None    # deprecated: use insert_layout instead
     insert_template = None    # deprecated: use detail_layout instead
@@ -704,14 +705,14 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             # subsequent calls, causing tracebacks like "AttributeError:
             # 'TableHandle' object has no attribute 'store'"
             setattr(self, hname, h)
-            if False:  # 20210610
+            if True:  # 20210610
                 settings.SITE.kernel.setup_handle(h, ar)
             else:
                 try:
                     settings.SITE.kernel.setup_handle(h, ar)
                 except Exception as e:
                     # traceback.print_exc()
-                    logger.warning("%s setup_handle failed with %s", self, e)
+                    logger.warning("%s setup_handle failed with %s (change actors.py to see more)", self, e)
                     delattr(self, hname)
                     # raise
 
@@ -832,6 +833,10 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         #     print("20200825 {}.register_params {} {}".format(
         #         cls, cls.parameters, cls.params_layout))
 
+    # @classmethod
+    # def collect_extra_fields(cls, fld):
+    #     cls.extra_fields[fld.name] = fld
+
     @classmethod
     def collect_virtual_fields(cls):
 
@@ -1605,16 +1610,23 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         # Note that there are models with fields named 'master', 'app_label',
         # 'model' (i.e. a name that is also used as attribute of an actor.
 
-        vf = self.virtual_fields.get(name, None)
-        if vf is not None:
-            #~ logger.info("20120202 Actor.get_data_elem found vf %r",vf)
-            return vf
+        for cls in getmro(self):
+            if hasattr(cls, 'virtual_fields'):
+                vf = cls.virtual_fields.get(name, None)
+                if vf is not None:
+                    #~ logger.info("20120202 Actor.get_data_elem found vf %r",vf)
+                    return vf
 
         if self.model is not None:
             de = self.model.get_data_elem(name)
             if de is not None:
                 return de
 
+        # if len(self.extra_fields):
+        #     ef = self.extra_fields.get(name)
+        #     if ef:
+        #         return ef
+
         a = getattr(self, name, None)
         if isinstance(a, actions.Action):
             return a
