@@ -48,11 +48,18 @@ URL_PARAM_WINDOW_TYPE = 'wt'
 
 WINDOW_TYPE_TABLE = "t"
 WINDOW_TYPE_DETAIL = "d"
-WINDOW_TYPE_INSERT = "i"
 WINDOW_TYPE_CARDS = "c"
-WINDOW_TYPE_PARAMS = "p"
 WINDOW_TYPE_GALLERIA = "g"
+WINDOW_TYPE_INSERT = "i"
+WINDOW_TYPE_PARAMS = "p"
 
+DISPLAY_MODE_TABLE = "grid"
+DISPLAY_MODE_DETAIL = "detail"
+DISPLAY_MODE_CARDS = "cards"
+DISPLAY_MODE_LIST = "list"
+DISPLAY_MODE_GALLERY = "gallery"
+DISPLAY_MODE_SUMMARY = "summary"
+DISPLAY_MODE_HTML = "html"
 
 #~ URL_PARAM_EUSER = 'euser'
 #~ URL_PARAM_EUSER = 'su'
