@@ -299,6 +299,7 @@ class Table(AbstractTable):
         """
         try:
             return self.model.get_user_queryset(ar.get_user()).get(pk=pk)
+            # return self.get_queryset(ar).get(pk=pk)
         except ValueError:
             return None
         except self.model.DoesNotExist:
@@ -680,22 +681,6 @@ class Table(AbstractTable):
               return self.model.objects.select_related('country', 'city')
 
         """
-        assert not self.model._meta.abstract
-        # if self.model._meta.abstract:
-        #     lst = list(models_by_base(self.model))
-        #     qs = lst[0].get_request_queryset(ar, **filter)
-        #     if len(lst) > 1:
-        #         flds = self.get_handle().store.list_fields
-        #         flds = set([
-        #             f.name for f in flds
-        #             if isinstance(f.field, models.Field)])
-        #         flds |= self.hidden_elements
-        #         # flds = self.column_names.split()
-        #         qs = qs.only(*flds)
-        #         for m in lst[1:]:
-        #             qs = qs.union(m.get_request_queryset(ar, **filter).only(*flds))
-        #         # raise Exception("20170905 {} {}".format(flds, qs.query))
-        #     return qs
         return self.model.get_request_queryset(ar, **filter)
 
     @classmethod
