@@ -210,6 +210,7 @@ class FakeField(object):
     """
     Base class for :class:`RemoteField` and :class:`DisplayField`.
     """
+    _lino_atomizer = None
     model = None
     db_column = None
     choices = []
@@ -228,7 +229,7 @@ class FakeField(object):
     generate_reverse_relation = False  # needed when AFTER17
     remote_field = None
     blank = True  # 20200425
-    asynchronous = False
+    delayed_value = False
 
     wildcard_data_elem = False
     """Whether to consider this field as wildcard data element.
@@ -1157,6 +1158,12 @@ class TableRow(object):
     def get_choices_text(self, request, actor, field):
         return str(self)
 
+    # @htmlbox()
+    # def table_summary(self, ar):
+    #     if ar is None:
+    #         return ''
+    #     return ar.actor.get_table_summary(self, ar)
+
     # @fields.displayfield(_("Description"))
     # @fields.htmlbox(_("Overview"))
     @htmlbox()
