@@ -715,10 +715,10 @@ class Kernel(object):
             yield gfk, fk_field, ct.get_all_objects_for_this_type(**kw)
 
     def get_broken_generic_related(self, model):
-        """Yield all database objects of this model which have some broken
+        """Yield all database objects of this model that have some broken
         GFK field.
 
-        This is a slow query which does an additional database request
+        This is a slow query, which does an additional database request
         for each row. (Is there a possibility to do this in a single
         SQL query?)
 
