@@ -102,7 +102,7 @@ class LayoutHandle(object):
         self.layout = layout
         self.ui = ui
         self.hidden_elements = layout.hidden_elements
-        self._store_fields = []
+        self._data_elems = []
         self._names = {}
 
         # self.define_panel('main', layout.main)
@@ -334,8 +334,8 @@ class LayoutHandle(object):
     def __getitem__(self, name):
         return self._names[name]
 
-    def add_store_field(self, field):
-        self._store_fields.append(field)
+    def add_data_elem(self, field):
+        self._data_elems.append(field)
 
     def get_title(self, ar):
         return self.layout.get_title(ar)
@@ -620,7 +620,11 @@ add_tabpanel() on %s horizontal 'main' panel %r."""
     def get_layout_handle(self, ui=None):
         """
         Return the LayoutHandle for this layout on the specified front end `ui`.
-        Create a LayoutHandle instance if this is the first call.        
+        Create a LayoutHandle instance if this is the first call.
+
+        TODO: replace get_layout_handle by a simple property. We no longer have
+        Lino sites with several front ends
+
         """
         if ui is None:
             ui = settings.SITE.kernel.default_ui
