@@ -171,7 +171,7 @@ class Plugin(object):
     """
 
     support_async = False
-    """Whether this plugin supports usage of :class:`lino.utils.AsynchronousValue`."""
+    """Whether this plugin supports usage of :class:`lino.utils.DelayedValue`."""
 
 
     renderer = None
