@@ -161,6 +161,58 @@ class HtmlRenderer(Renderer):
         return ''.join([
             tostring(e) for e in self.table2story(*args, **kwargs)])
 
+    def show_detail(self, ar, *args, **kwargs):
+        """Show the window that is to be opened by `ar`.
+
+        The output is currently gives no beautiful representation of the window,
+        but at least it renders all content. This is the first intended purpose:
+        to test whether things work.
+
+        """
+        from bs4 import BeautifulSoup
+        import rstgen
+        lh = ar.bound_action.get_layout_handel()
+        # print("20210615 show_detail()", ar.bound_action, lh.layout)
+        obj = None
+        if ar.bound_action.action.select_rows:
+            if len(ar.selected_rows) > 0:
+                obj = ar.selected_rows[0]
+        chunks = []
+
+        def tag2rst(t, level=1):
+            items = []
+            simple = True
+            for c in t.children:
+                s = c.string
+                if s:
+                    items.append(s)
+                else:
+                    simple = False
+                    s = tag2rst(c)
+                    if s:
+                        items.append(s)
+            if simple:
+                return ', '.join(items)
+            else:
+                return rstgen.ul(items)
+
+        with ar.get_user().user_type.context():
+            html = tostring(lh.main.as_plain_html(ar, obj))
+            soup = BeautifulSoup(html, 'lxml')
+            print(soup.get_text().strip())
+            # print(tag2rst(soup.get_text()))
+            # print(soup.prettify())
+            # print(html)
+            # print(tag2rst(soup.body))
+
+            # for e in lh.walk():
+            #     chunks.extend(e.as_plain_html(ar, obj))
+            #     # for frag in e.as_plain_html(ar, obj):
+            #     #     if frag is not None:
+            #     #         chunks.append(frag)
+            # for ch in chunks:
+            #     print(tostring(ch))
+
     def html_text(self, html):
         """Render a chunk of HTML text.
 
