@@ -1128,7 +1128,7 @@ class BaseRequest(object):
         """
         lh = ah.actor.insert_layout.get_layout_handle(
             settings.SITE.kernel.default_ui)
-        fields = [df._lino_atomizer for df in lh._store_fields]
+        fields = [df._lino_atomizer for df in lh._data_elems]
         if ah.store._disabled_fields_storefield is not None:
             fields.append(ah.store._disabled_fields_storefield)
         rec = self.elem2rec1(ah, elem, fields=fields)
