@@ -30,6 +30,7 @@ import datetime
 
 from django.conf import settings
 from django.db import models
+from django.db.models.fields import Field
 from django.core import exceptions
 from django.utils.translation import gettext_lazy as _
 from django.utils.encoding import force_str
@@ -38,10 +39,12 @@ from lino import AFTER17
 from lino.utils.jsgen import py2js
 from lino.utils.quantities import parse_decimal
 from lino.core.utils import getrqdata
+from lino.core.gfks import GenericForeignKey
 
 from lino.core import constants
 
 from lino.core import fields
+from lino.core import actors
 from lino.core import actions
 from lino.core import frames
 from lino.utils import choosers
@@ -50,7 +53,7 @@ from lino.utils import iif
 from lino.utils.format_date import fds
 from lino.core.requests import PhantomRow
 from lino.utils import IncompleteDate
-from lino.utils import AsynchronousValue
+from lino.utils import DelayedValue
 
 
 class StoreField(object):
@@ -80,18 +83,21 @@ class StoreField(object):
     list_values_count = 1
     "Necessary to compute :attr:`Store.pk_index`."
 
-    asynchronous = False
+    delayed_value = False
 
     def __init__(self, field, name, **options):
+        # if not isinstance(field, (fields.FakeField, Field, GenericForeignKey)):
+        #     raise Exception("20210623 {} is not a field".format(field))
         self.field = field
         self.name = str(name)  # TypeError 20160425
         self.options = options
         # if settings.SITE.kernel.default_ui.support_async:
         if settings.SITE.default_ui == "lino_react.react":
-            if isinstance(field, fields.FakeField) and field.asynchronous:
-                self.asynchronous = True
-                self.asynchronous = False  # wip
-                # print("20210610 asynchronous", name)
+            if isinstance(field, fields.FakeField) and field.delayed_value:
+                self.delayed_value = True
+                # print("20210619 StoreField.delayedValue is True", name)
+            # else:
+            #     print("20210619 StoreField.delayedValue is False", name)
 
     def as_js(self, name):
         """
@@ -541,7 +547,7 @@ class DisabledFieldsStoreField(SpecialStoreField):
     name = str('disabled_fields')
 
     def __init__(self, store):
-        from lino.core.gfks import GenericForeignKey
+        # from lino.core.gfks import GenericForeignKey
         SpecialStoreField.__init__(self, store)
         self.always_disabled = set()
         for f in self.store.all_fields:
@@ -829,8 +835,8 @@ class MethodStoreField(StoreField):
 
     def value_from_object(self, obj, request=None):
         unbound_meth = self.field._return_type_for_method
-        assert unbound_meth.__code__.co_argcount >= 2, (self.name,
-                                                         unbound_meth.__code__.co_varnames)
+        assert unbound_meth.__code__.co_argcount >= 2, (
+            self.name, unbound_meth.__code__.co_varnames)
         # print self.field.name
         return unbound_meth(obj, request)
 
@@ -878,12 +884,20 @@ class OneToOneRelStoreField(StoreField):
 
 def get_atomizer(holder, fld, name):
     """
-    Return the atomizer for this database field. The atomizer is an
-    instance of a subclass of :class:`StoreField`.
+    Return the :term:`atomizer` for this database field.
+
+    An atomizer is an instance of a subclass of :class:`StoreField`.
+
     """
     sf = getattr(fld, '_lino_atomizer', None)
     if sf is None:
         sf = create_atomizer(holder, fld, name)
+        if sf is None:
+            # print("20210623 {} on {} has no StoreField".format(name, holder))
+            return
+        assert isinstance(sf, StoreField)
+        # if not isinstance(sf, StoreField):
+        #     raise Exception("{} is not a StoreField".format(sf))
         setattr(fld, '_lino_atomizer', sf)
     return sf
 
@@ -927,15 +941,18 @@ def create_atomizer(holder, fld, name):
         # uh, this is tricky...
         return MethodStoreField(fld, name)
 
-    sf_class = getattr(fld, 'lino_atomizer_class', None)
-    if sf_class is not None:
-        return sf_class(fld, name)
+    # sf_class = getattr(fld, 'lino_atomizer_class', None)
+    # if sf_class is not None:
+    #     return sf_class(fld, name)
 
     if isinstance(fld, fields.DummyField):
         return None
     if isinstance(fld, fields.RequestField):
         delegate = create_atomizer(holder, fld.return_type, fld.name)
         return RequestStoreField(fld, delegate, name)
+    # if isinstance(fld, type) and issubclass(fld, actors.Actor):
+    #     # 20210618
+    #     return DisplayStoreField(fld, name)
     if isinstance(fld, fields.VirtualField):
         delegate = create_atomizer(holder, fld.return_type, fld.name)
         if delegate is None:
@@ -1009,7 +1026,7 @@ class ParameterStore(BaseStore):
 
         holder = params_layout_handle.layout.get_chooser_holder()
         # debug = False
-        for pf in params_layout_handle._store_fields:
+        for pf in params_layout_handle._data_elems:
             sf = create_atomizer(holder, pf, pf.name)
             if sf is not None:
                 # if "__" in pf.name:
@@ -1106,7 +1123,7 @@ class Store(BaseStore):
         self.actor = rh.actor
 
         # temporary dict used by collect_fields and add_field_for
-        self.df2sf = {}
+        # self.df2sf = {}
         self.all_fields = []
         self.list_fields = []
         self.detail_fields = []
@@ -1115,6 +1132,8 @@ class Store(BaseStore):
         self.primary_keys = set([])
 
         def addfield(sf):
+            if not isinstance(sf, StoreField):
+                raise Exception("20210623 {} is not a StoreField".format(sf))
             self.all_fields.append(sf)
             self.list_fields.append(sf)
             self.detail_fields.append(sf)
@@ -1168,19 +1187,12 @@ class Store(BaseStore):
                 raise Exception("Primary key %r not found in list_fields %s" %
                                 (self.pk, [f.field for f in self.list_fields]))
 
-        del self.df2sf
-
-        # if not issubclass(rh.report,dbtables.Table):
-            # addfield(RecnoStoreField(self))
-
         actor_editable = True  # not rh.actor.hide_editing(None)
         if actor_editable:
             self._disabled_fields_storefield = DisabledFieldsStoreField(self)
             addfield(self._disabled_fields_storefield)
             # NB what about disabled actions on non-editable actor?
 
-        # addfield(DisabledActionsStoreField(self))
-
         if actor_editable:
             addfield(DisableEditingStoreField(self))
 
@@ -1208,7 +1220,7 @@ class Store(BaseStore):
         """
         pk_found = False
         for layout in layouts:
-            for df in layout._store_fields:
+            for df in layout._data_elems:
                 assert df is not None
                 self.add_field_for(fields, df)
                 if df.primary_key:
@@ -1232,8 +1244,10 @@ class Store(BaseStore):
             if isinstance(df, fields.DummyField):
                 return
             return
-            raise Exception("20181023 No atomizer for {} in {}".format(
-                repr(df), self.actor))
+            # raise Exception("20181023 No atomizer for {} in {}".format(
+            #     repr(df), self.actor))
+        if not isinstance(sf, StoreField):
+            raise Exception("20210623 {} is not a StoreField".format(sf))
         # if not self.rh.actor.editable and isinstance(sf, ForeignKeyStoreField):
         #     sf = StoreField(df, df.name)
         #     raise Exception(20160907)
@@ -1309,8 +1323,9 @@ class Store(BaseStore):
                 fld.value2list(ar, None, l, row)
         else:
             for fld in self.list_fields:
-                if fld.asynchronous:
-                    v = AsynchronousValue(fld, row)
+                if fld.delayed_value:
+                    # self.actor.collect_extra_fields(fld)
+                    v = DelayedValue(ar, fld.name, row)
                 else:
                     v = fld.full_value_from_object(row, ar)
                 fld.value2list(ar, v, l, row)
@@ -1326,8 +1341,9 @@ class Store(BaseStore):
             if fld is None:
                 continue
             # logger.info("20140429 Store.row2dict %s", fld)
-            if fld.asynchronous:
-                v = AsynchronousValue(fld, row)
+            if fld.delayed_value:
+                # self.actor.collect_extra_fields(fld)
+                v = DelayedValue(ar, fld.name, row)
             else:
                 v = fld.full_value_from_object(row, ar)
             fld.value2dict(ar, fld.name, v, d, row)
