@@ -1,13 +1,13 @@
 # Copyright 2012-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import re
 from html import escape
 import datetime
 
 # from django.contrib.humanize.templatetags.humanize import naturaltime
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ugettext as gettext
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext
 from django.conf import settings
 
 
@@ -20,7 +20,7 @@ from etgen.html import E
 
 from lino.api import rt, dd
 from .roles import SiteSearcher
-from .choicelists import TimeZones
+from .choicelists import TimeZones, DateFormats
 
 def dtfmt(dt):
     if isinstance(dt, float):
