@@ -137,9 +137,6 @@ class Plugin(ad.Plugin):
                         }
                     });
                 });
-                if ('serviceWorker' in navigator) {
-                    navigator.serviceWorker.register('/service-worker.js');
-                }
             </script>"""
 
         if not self.use_websockets:
