@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging ; logger = logging.getLogger(__name__)
@@ -14,7 +14,6 @@ from django.utils import timezone
 from django.utils import translation
 from etgen.html import E, tostring
 
-from lino import DJANGO2
 from lino.api import dd, rt, _
 
 # from lino.core.roles import SiteStaff
@@ -102,6 +101,15 @@ class ClearSeen(dd.Action):
             obj.save()
         ar.success(refresh_all=True)
 
+if dd.plugins.notify.use_push_api:
+
+    class Subscription(UserAuthored):
+        allow_cascaded_delete = ['user']
+        lang = models.CharField(max_length=30, null=True, blank=True)
+        userAgent = models.CharField(max_length=200, null=True, blank=True)
+        endpoint = models.URLField(max_length=500)
+        p256dh = models.CharField(max_length=300)
+        auth = models.CharField(max_length=150)
 
 
 class Message(UserAuthored, Controllable, Created):
@@ -114,7 +122,7 @@ class Message(UserAuthored, Controllable, Created):
     message_type = MessageTypes.field(default="change")
     seen = models.DateTimeField(_("seen"), null=True, editable=False)
     sent = models.DateTimeField(_("sent"), null=True, editable=False)
-    body = dd.RichTextField(_("Body"), editable=False, format='html')
+    body = dd.RichTextField(_("Body"), editable=False, format='html', default='')
     mail_mode = MailModes.field(default=MailModes.as_callable('often'))
     subject = models.CharField(
         _("Subject"), max_length=250, editable=False)
@@ -128,18 +136,33 @@ class Message(UserAuthored, Controllable, Created):
     # return _("Notify {0} about change on {1}").format(
     #     self.user, self.owner)
 
+    @classmethod
+    def emit_broadcast_notification(cls,
+        msg, owner=None, message_type=None, push_options={},
+        **msgdata):
+        cls.create_message(
+            None, owner, push_options=push_options,
+            body=msg, subject="Broadcast message",
+            message_type=message_type, **msgdata)
+
     @classmethod
     def emit_notification(
             cls, ar, owner, message_type, msg_func, recipients):
-        # recipients = list(recipients)
-        # dd.logger.info(
-        #     "20180612 %s emit_notification() for %d recipients",
-        #     owner, len(recipients))
-
+        """
+        ATM the action_url is computed using the permissions of the sending user.
+        That's maybe not exactly what we want (the url should depend on the recipient).
+        But until now we cannot imagine any case where this would become important.
+        """
+        push_options = {}
         # remove recipients without user:
         if ar is None:
             me = None
         else:
+            if owner is not None:
+                ba = owner.get_detail_action(ar)
+                if ba is not None:
+                    push_options.update(action_url=ar.renderer.get_detail_url(ar, ba.actor, owner.pk))
+                # push_options.update(action_url=ar.renderer.obj2url(ar, owner))
             me = ar.get_user()
         others = set()
         for user, mm in recipients:
@@ -165,23 +188,34 @@ class Message(UserAuthored, Controllable, Created):
                     if subject_body is not None:
                         subject, body = subject_body
                         cls.create_message(
-                            user, owner, body=body,
-                            subject=subject,
+                            user, owner, push_options=push_options,
+                            body=body, subject=subject,
                             mail_mode=mm, message_type=message_type)
 
     @classmethod
-    def create_message(cls, user, owner=None, **kwargs):
-        if owner is not None:
+    def create_message(cls, user, owner=None, push_options={}, **msgdata):
+        if owner is not None and user is not None:
             fltkw = gfk2lookup(cls.owner, owner)
             qs = cls.objects.filter(
                 user=user, seen__isnull=True, **fltkw)
             if qs.exists():
                 return
-        obj = cls(user=user, owner=owner, **kwargs)
+        obj = cls(user=user, owner=owner, **msgdata)
         obj.full_clean()
         obj.save()
-        if settings.SITE.use_websockets:
-            obj.send_browser_message(user)
+        # Encode and send that message to the whole channels Group for our
+        # Websocket. Note how you can send to a channel or Group from any part
+        # of Django, not just inside a consumer.
+        # logger.info("Sending browser notification to %s", user or "everyone")
+        push_options.update(
+            primary_key=obj.id,  # needed for use_websockets
+            # subject=str(self.subject),
+            subject=settings.SITE.title,
+            # body=settings.SITE.plugins.memo.parser.parse(obj.body),
+            body=html2text(obj.body),
+            created=obj.created)
+        send_notification(user, **push_options)
+
 
     mark_all_seen = MarkAllSeen()
     mark_seen = MarkSeen()
@@ -225,54 +259,22 @@ class Message(UserAuthored, Controllable, Created):
                         msg.seen = timezone.now()
                     msg.save()
 
-    def send_browser_message_for_all_users(self, user):
-
-        message = {
-            "id": self.id,
-            "subject": self.subject,
-            "body": html2text(self.body),
-            "created": self.created.strftime("%a %d %b %Y %H:%M"),
-        }
-
-        # Encode and send that message to the whole channels Group for our
-        # liveblog. Note how you can send to a channel or Group from any part
-        # of Django, not just inside a consumer.
-        if not DJANGO2:
-            from channels import Group
-            Group(PUBLIC_GROUP).send({
-                # WebSocket text frame, with JSON content
-                "text": json.dumps(message),
-            })
-        else:
-            from channels.layers import get_channel_layer
-            channel_layer = get_channel_layer()
-            from asgiref.sync import async_to_sync
-            async_to_sync(channel_layer.group_send)(PUBLIC_GROUP, {"text": json.dumps(message)})
-
-        return
-
-    def send_browser_message(self, user):
-
-        message = {
-            "id": self.id,
-            "subject": str(self.subject),
-            "body": html2text(self.body),
-            "created": self.created.strftime("%a %d %b %Y %H:%M"),
-        }
-
-        # Encode and send that message to the whole channels Group for our
-        # Websocket. Note how you can send to a channel or Group from any part
-        # of Django, not just inside a consumer.
-        logger.info("Sending browser notification to %s", user.username)
-        if not DJANGO2:
-            from channels import Group
-            Group(groupname(user.username)).send({
-                # WebSocket text frame, with JSON content
-                "text": json.dumps(message),
-            })
-        else:
-            send_notification(user, **message)
-        return
+    # def send_browser_message_for_all_users(self, user):
+    #     # not maintained. appearently not used.
+    #     message = {
+    #         "id": self.id,
+    #         "subject": self.subject,
+    #         "body": html2text(self.body),
+    #         "created": self.created.strftime("%a %d %b %Y %H:%M"),
+    #     }
+    #
+    #     # Encode and send that message to the whole channels Group for our
+    #     # liveblog. Note how you can send to a channel or Group from any part
+    #     # of Django, not just inside a consumer.
+    #     from channels.layers import get_channel_layer
+    #     channel_layer = get_channel_layer()
+    #     from asgiref.sync import async_to_sync
+    #     async_to_sync(channel_layer.group_send)(PUBLIC_GROUP, {"text": json.dumps(message)})
 
 
 dd.update_field(Message, 'user',
@@ -372,9 +374,14 @@ class MyMessages(My, Messages):
 
     @classmethod
     def get_table_summary(cls, mi, ar):
-        qs = rt.models.notify.Message.objects.filter(
-            user=ar.get_user()).order_by(cls.created_order)
-        qs = qs.filter(seen__isnull=True)
+        u = ar.get_user()
+        if u.is_authenticated:
+            qs = rt.models.notify.Message.objects.filter(
+                user=u).order_by(cls.created_order)
+            qs = qs.filter(seen__isnull=True)
+        else:
+            qs = rt.models.notify.Message.objects.filter(
+                user__isnull=True).order_by(cls.created_order)
         # mark_all = rt.models.notify.MyMessages.get_action_by_name(
         #     'mark_all_seen')
         # html = tostring(ar.action_button(mark_all, None))
