@@ -20,11 +20,14 @@ class Plugin(ad.Plugin):
 
     needs_plugins = ['lino.modlib.printing']
 
+    use_dashboard_layouts = False
+    """Whether to use system.DashboardLayouts.
+    """
+
     def setup_config_menu(self, site, user_type, m):
         system = m.add_menu(self.app_label, self.verbose_name)
         system.add_instance_action(site.site_config)
 
-
     def on_site_startup(self, site):
         super(Plugin, self).on_site_startup(site)
 
