@@ -1,5 +1,5 @@
 # Copyright 2009-2016 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines Lino default settings. You include this (directly or
 indirectly) into your local :xfile:`settings.py` using::
@@ -8,22 +8,22 @@ indirectly) into your local :xfile:`settings.py` using::
 
 """
 
-from lino.api.ad import Site, configure_plugin, _
+from lino.api.ad import Site, configure_plugin
 
 
-# def TIM2LINO_LOCAL(alias, obj):
-#     """Hook for local special treatment on instances that have been
-#     imported from TIM.
-#
-#     """
-#     return obj
-#
-#
-# def TIM2LINO_USERNAME(userid):
-#     if userid == "WRITE":
-#         return None
-#     return userid.lower()
-#
+def TIM2LINO_LOCAL(alias, obj):
+    """Hook for local special treatment on instances that have been
+    imported from TIM.
+
+    """
+    return obj
+
+
+def TIM2LINO_USERNAME(userid):
+    if userid == "WRITE":
+        return None
+    return userid.lower()
+
 
 DEBUG = False
 TEMPLATE_DEBUG = DEBUG
