@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2011-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This middleware is automatically being installed on every Lino
 site.
@@ -53,7 +53,8 @@ class AjaxExceptionResponse(MiddlewareMixin):
     # exceptions on a production site in order to debug problems like #2699
 
     def process_exception(self, request, exception):
-        if request.is_ajax():
+        # if request.is_ajax():  # See https://docs.djangoproject.com/en/3.1/releases/3.1/
+        if request.headers.get('x-requested-with') == 'XMLHttpRequest':
             (exc_type, exc_info, tb) = sys.exc_info()
 
             # response to client:
@@ -62,12 +63,12 @@ class AjaxExceptionResponse(MiddlewareMixin):
 
             if not isinstance(exception, self.no_traceback):
                 # message to be logged:
-                msg = "AjaxExceptionResponse {0}\n".format(response)
+                msg = "AjaxExceptionResponse {0}".format(response)
                 msg += "\nin request {0}\n".format(format_request(request))
-                msg += "TRACEBACK:\n"
-                for tb in traceback.format_tb(tb):
-                    msg += smart_text(tb)
                 if settings.DEBUG:
+                    msg += "TRACEBACK:\n"
+                    for tb in traceback.format_tb(tb):
+                        msg += smart_text(tb)
                     settings.SITE.logger.warning(msg)
                 else:
                     settings.SITE.logger.exception(msg)
@@ -76,5 +77,3 @@ class AjaxExceptionResponse(MiddlewareMixin):
             # if isinstance(exception, ObjectDoesNotExist):
             #     return HttpResponseBadRequest(response)
             # return HttpResponseServerError(response)
-
-
