@@ -315,7 +315,7 @@ def layout_fields(ba):
     if wl is None:
         return ''
     lh = wl.get_layout_handle(settings.SITE.kernel.default_ui)
-    elems = [str(f.name) for f in lh._store_fields if not isinstance(f, DummyField)]
+    elems = [str(f.name) for f in lh._data_elems if not isinstance(f, DummyField)]
     return ', '.join(elems)
     # return fill(' '.join(elems), 50)
 
