@@ -46,7 +46,7 @@ from etgen import etree
 from lino.utils import IncompleteDate
 from lino.utils.quantities import Quantity
 from lino.utils import curry
-from lino.utils import AsynchronousValue
+from lino.utils import DelayedValue
 from lino.core.permissions import Permittable
 from lino.core.permissions import make_static_permission_handler
 from lino.modlib.users.utils import get_user_profile
@@ -401,8 +401,10 @@ def py2js(v, compact=True):
     """Note that None values are rendered as ``null`` (not ``undefined``.
 
     """
-    if isinstance(v, AsynchronousValue):
-        v = dict(field=v.field.name, pk=v.obj.pk)
+    if isinstance(v, DelayedValue):
+        # v = dict(field=v.field.name, pk=v.obj.pk)
+        v = dict(delayed_value_url=v.get_url())
+        # print("20210619", v)
 
     for cv in CONVERTERS:
         v = cv(v)
