@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2013-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """Defines the :class:`MediaFile` class.
 """
 
@@ -59,11 +59,3 @@ class TmpMediaFile(MediaFile):
         ip = ar.request.META.get('REMOTE_ADDR', 'unknown_ip')
         super(TmpMediaFile, self).__init__(
             False, 'cache', 'appy' + fmt, ip, str(ar.actor) + '.' + fmt)
-
-
-def _test():
-    import doctest
-    doctest.testmod()
-
-if __name__ == "__main__":
-    _test()
